@@ -1,7 +1,6 @@
 """Adaptive Smoothed Aggregation"""
 from __future__ import absolute_import
 
-__docformat__ = "restructuredtext en"
 
 from warnings import warn
 import numpy as np
@@ -12,15 +11,15 @@ from scipy.sparse import csr_matrix, bsr_matrix, isspmatrix_csr,\
 from pyamg.multilevel import multilevel_solver
 from pyamg.strength import symmetric_strength_of_connection,\
     classical_strength_of_connection, evolution_strength_of_connection
-from ..relaxation.relaxation import gauss_seidel, gauss_seidel_nr, gauss_seidel_ne,\
-    gauss_seidel_indexed, jacobi, polynomial
+from ..relaxation.relaxation import gauss_seidel, gauss_seidel_nr,\
+    gauss_seidel_ne, gauss_seidel_indexed, jacobi, polynomial
 from pyamg.relaxation.smoothing import change_smoothers, rho_D_inv_A
 from pyamg.krylov import gmres
 from pyamg.util.linalg import norm, approximate_spectral_radius
 from .aggregation import smoothed_aggregation_solver
 from .aggregate import standard_aggregation, lloyd_aggregation
-from .smooth import jacobi_prolongation_smoother, energy_prolongation_smoother,\
-    richardson_prolongation_smoother
+from .smooth import jacobi_prolongation_smoother,\
+    energy_prolongation_smoother, richardson_prolongation_smoother
 from .tentative import fit_candidates
 from pyamg.util.utils import amalgamate, levelize_strength_or_aggregation, \
     levelize_smooth_or_improve_candidates
@@ -113,7 +112,7 @@ def unpack_arg(v):
 def adaptive_sa_solver(A, initial_candidates=None, symmetry='hermitian',
                        pdef=True, num_candidates=1, candidate_iters=5,
                        improvement_iters=0, epsilon=0.1,
-                       max_levels=10, max_coarse=100, aggregate='standard',
+                       max_levels=10, max_coarse=10, aggregate='standard',
                        prepostsmoother=('gauss_seidel',
                                         {'sweep': 'symmetric'}),
                        smooth=('jacobi', {}), strength='symmetric',
@@ -399,7 +398,7 @@ def initial_setup_stage(A, symmetry, pdef, candidate_iters, epsilon,
                    omega=1.0 / rho_D_inv_A(A))
         elif fn == 'richardson':
             polynomial(A, x, np.zeros_like(x), iterations=1,
-                       coeffients=[1.0/approximate_spectral_radius(A)])
+                       coefficients=[1.0/approximate_spectral_radius(A)])
         elif fn == 'gmres':
             x[:] = (gmres(A, np.zeros_like(x), x0=x,
                     maxiter=candidate_iters)[0]).reshape(x.shape)
@@ -748,7 +747,7 @@ def general_setup_stage(ml, symmetry, candidate_iters, prepostsmoother,
 
         elif fn == 'richardson':
             polynomial(lvl.A, x, np.zeros_like(x), iterations=1,
-                       coeffients=[1.0/approximate_spectral_radius(lvl.A)])
+                       coefficients=[1.0/approximate_spectral_radius(lvl.A)])
 
         elif fn == 'gmres':
             x[:] = (gmres(lvl.A, np.zeros_like(x), x0=x,
